-- This script creates Long Running Execution Environment tables on a db2 instance.
-- The default name of the database is LREE, default schema name is
-- LREESCHEMA and default tablespace is USERSPACE1. All these defaults
-- can be replaced with different names if needed.
-- The following command can be issued from DB2 command line processor
-- to run this script:
--             db2 -tf CreateLREETablesDB2.ddl
--



CONNECT TO LREE;




CREATE SCHEMA LREESCHEMA;


------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."BJEELOGMESSAGES"

------------------------------------------------

 

 CREATE TABLE "LREESCHEMA"."BJEELOGMESSAGES"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "MSGSEQ" INTEGER NOT NULL , 

		  "MSGTXT" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."BJEELOGMESSAGES"



ALTER TABLE "LREESCHEMA"."BJEELOGMESSAGES" 

	ADD CONSTRAINT "PK_BJEELOGMESSAGES" PRIMARY KEY

		("JOBID",

		 "MSGSEQ");







------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."LOCALJOBSTATUS"

------------------------------------------------

 

 CREATE TABLE "LREESCHEMA"."LOCALJOBSTATUS"  (

		  "BJEENAME" VARCHAR(250) NOT NULL , 

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "STATUS" INTEGER NOT NULL , 

		  "STATUSTXT" VARCHAR(250) , 

		  "CURRENTSTEP" VARCHAR(250) , 

		  "RC" INTEGER NOT NULL , 

		  "UPDATECOUNT" INTEGER NOT NULL , 

		  "SUSPENDEDUNTIL" VARCHAR(250) ,

		  "LASTUPDATE" VARCHAR(250) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."LOCALJOBSTATUS"



ALTER TABLE "LREESCHEMA"."LOCALJOBSTATUS" 

	ADD CONSTRAINT "PK_LOCALJOBSTATUS" PRIMARY KEY

		("BJEENAME",

		 "JOBID");






------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."ABSTRACTRESOURCE"

------------------------------------------------

 

 CREATE TABLE "LREESCHEMA"."ABSTRACTRESOURCE"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "NAME" VARCHAR(250) NOT NULL , 

		  "TYPE1" VARCHAR(250) , 

		  "STRINGVALUE" VARCHAR(250) , 

		  "INTEGERVALUE" INTEGER )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."ABSTRACTRESOURCE"



ALTER TABLE "LREESCHEMA"."ABSTRACTRESOURCE" 

	ADD CONSTRAINT "PK_ABSTRACTRESOUR1" PRIMARY KEY

		("JOBID",

		 "NAME");






------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."CHECKPOINTREPOSITORY"

------------------------------------------------


-- Maximum length of RESTARTTOKEN (in bytes) : 2970
-- source: http://publib.boulder.ibm.com/infocenter/db2luw/v8/index.jsp
 

 CREATE TABLE "LREESCHEMA"."CHECKPOINTREPOSITORY"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "STEPNAME" VARCHAR(250) NOT NULL , 

		  "BATCHDATASTREAMNAME" VARCHAR(250) NOT NULL , 

		  "RESTARTTOKEN" VARCHAR(2970) )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."CHECKPOINTREPOSITORY"



ALTER TABLE "LREESCHEMA"."CHECKPOINTREPOSITORY" 

	ADD CONSTRAINT "PK_CHECKPOINTREPO2" PRIMARY KEY

		("JOBID", "STEPNAME" ,

		 "BATCHDATASTREAMNAME");






------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."JOBSTEPSTATUS"

------------------------------------------------

 

 CREATE TABLE "LREESCHEMA"."JOBSTEPSTATUS"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "STEPNAME" VARCHAR(250) NOT NULL , 

		  "RC" INTEGER NOT NULL , 

		  "STEPSTATUS" INTEGER NOT NULL )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."JOBSTEPSTATUS"



ALTER TABLE "LREESCHEMA"."JOBSTEPSTATUS" 

	ADD CONSTRAINT "PK_JOBSTEPSTATUS" PRIMARY KEY

		("JOBID",

		 "STEPNAME");






------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."JOBRESULTS"

------------------------------------------------

 

 CREATE TABLE "LREESCHEMA"."JOBRESULTS"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "RC" INTEGER NOT NULL , 

		  "INITIALIZED" SMALLINT NOT NULL )   

		 IN "USERSPACE1" ; 



-- DDL Statements for primary key on Table "LREESCHEMA"."JOBRESULTS"



ALTER TABLE "LREESCHEMA"."JOBRESULTS" 

	ADD CONSTRAINT "PK_JOBRESULTS" PRIMARY KEY

		("JOBID");

------------------------------------------------

-- DDL Statements for table "LREESCHEMA"."POJOSTEP"

------------------------------------------------

CREATE TABLE "LREESCHEMA"."POJOSTEP"  (

		  "JOBID" VARCHAR(250) NOT NULL , 

		  "STEPID" VARCHAR(250) NOT NULL )   

		 IN "USERSPACE1" ; 

ALTER TABLE "LREESCHEMA"."POJOSTEP" 

	ADD CONSTRAINT "PK_POJOSTEP" PRIMARY KEY

		("JOBID", "STEPID");



COMMIT WORK;



CONNECT RESET;



TERMINATE;

