-- This script creates Long Running Execution Environment tables on a Informix instance.
-- The default name of the database is LREE, default schema name is
-- LREESCHEMA and default tablespace is rootdbs. All these defaults
-- can be replaced with different names if needed.
-- The following command can be issued from Informix command line processor.
-- To run this script, type at cmd-line in <informix_install>/bin
-- dbaccess - CreateLreeTablesInformix.sql


CONNECT TO "LREE";


-- BEGIN WORK;

---------------------------------------
--DDL statements for SCHEMA: LREESCHEMA
---------------------------------------
CREATE SCHEMA AUTHORIZATION LREESCHEMA;


--------------------------------------------------------
--DDL statements for table: "LREESCHEMA.BJEELOGMESSAGES"
--------------------------------------------------------
CREATE TABLE LREESCHEMA.BJEELOGMESSAGES  (
		  JOBID VARCHAR(50) NOT NULL , 
		  MSGSEQ INTEGER NOT NULL , 
		  MSGTXT VARCHAR(250)
                  )
                  IN rootdbs;

---------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.BJEELOGMESSAGES"
---------------------------------------------------------------------
ALTER TABLE LREESCHEMA.BJEELOGMESSAGES
     ADD CONSTRAINT PRIMARY KEY(JOBID,MSGSEQ) CONSTRAINT PK_BJEELOGMESSAGES;


--------------------------------------------------------
--DDL statements for table: "LREESCHEMA.LOCALJOBSTATUS
--------------------------------------------------------
CREATE TABLE LREESCHEMA.LOCALJOBSTATuS  (

		 BJEENAME VARCHAR(250) NOT NULL , 

		 JOBID VARCHAR(50) NOT NULL , 

		 STATUS INTEGER NOT NULL , 

		 STATUSTXT VARCHAR(250) , 

		 CURRENTSTEP VARCHAR(250) , 

		 RC INTEGER NOT NULL , 

		 UPDATECOUNT INTEGER NOT NULL , 

		 SUSPENDEDUNTIL VARCHAR(250) ,

		 LASTUPDATE VARCHAR(250)
                 )
                 IN rootdbs;  
---------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.LOCALJOBSTATuS"
---------------------------------------------------------------------
ALTER TABLE LREESCHEMA.LOCALJOBSTATuS
     ADD CONSTRAINT PRIMARY KEY(JOBID,BJEENAME) CONSTRAINT PK_LOCALJOBSTATUS;



--------------------------------------------------------
--DDL statements for table: "LREESCHEMA.ABSTRACTRESOURCE"
--------------------------------------------------------
CREATE TABLE LREESCHEMA.ABSTRACTRESOURCE  (

		  JOBID VARCHAR(50) NOT NULL , 

		  NAME VARCHAR(250) NOT NULL , 

		  TYPE1 VARCHAR(250) , 

		  STRINGVALUE VARCHAR(250) , 

		  INTEGERVALUE INTEGER
                  )
                  IN rootdbs;  
		
----------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.ABSTRACTRESOURCE" 
----------------------------------------------------------------------
ALTER TABLE LREESCHEMA.ABSTRACTRESOURCE 
     ADD CONSTRAINT PRIMARY KEY(JOBID,NAME) CONSTRAINT PK_ABSTRACTRESOUR1;




------------------------------------------------------------
--DDL ststements for table: "LREESCHEMA.CHECKPOINTREPOSITORY"
------------------------------------------------------------
CREATE TABLE LREESCHEMA.CHECKPOINTREPOSITORY (
		  JOBID VARCHAR(50) NOT NULL , 
		  STEPNAME VARCHAR(50) NOT NULL , 
		  BATCHDATASTREAMNAME VARCHAR(250) NOT NULL , 
		  RESTARTTOKEN VARCHAR(200)
                  )
                  IN rootdbs; 

----------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.CHECKPOINTREPOSITORY"
----------------------------------------------------------------------
ALTER TABLE LREESCHEMA.CHECKPOINTREPOSITORY 
     ADD CONSTRAINT PRIMARY KEY(JOBID,STEPNAME,BATCHDATASTREAMNAME) CONSTRAINT PK_CHECKPOINTREPO2;



-----------------------------------------------------
--DDL statements for table: "LREESCHEMA.JOBSTEPSTATUS"
-----------------------------------------------------
CREATE TABLE LREESCHEMA.JOBSTEPSTATUS  (
		  JOBID VARCHAR(50) NOT NULL , 
		  STEPNAME VARCHAR(250) NOT NULL , 
		  RC INTEGER NOT NULL , 
		  STEPSTATUS INTEGER NOT NULL
                  )
                  IN rootdbs; 

----------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.JOBSTEPSTATUS"
----------------------------------------------------------------------
ALTER TABLE LREESCHEMA.JOBSTEPSTATUS 
     ADD CONSTRAINT PRIMARY KEY(JOBID,STEPNAME) CONSTRAINT PK_JOBSTEPSTATUS;





---------------------------------------------------
--DDL statements  for table: "LREESCHEMA.JOBRESULTS"
---------------------------------------------------
CREATE TABLE  LREESCHEMA.JOBRESULTS  (
		  JOBID VARCHAR(50) NOT NULL , 
		  RC INTEGER NOT NULL , 
		  INITIALIZED SMALLINT NOT NULL 
                  )
                  IN rootdbs;
		 
----------------------------------------------------------------------
--DDL statements for primary key on table: LREESCHEMA.JOBRESULTS
----------------------------------------------------------------------
ALTER TABLE LREESCHEMA.JOBRESULTS 
     ADD CONSTRAINT PRIMARY KEY(JOBID) CONSTRAINT PK_JOBRESULTS;


-----------------------------------------------------
--DDL statements for table: "LREESCHEMA.POJOSTEP"
-----------------------------------------------------
CREATE TABLE LREESCHEMA.POJOSTEP  (
		  JOBID VARCHAR(50) NOT NULL , 
		  STEPID VARCHAR(250) NOT NULL
                  )
                  IN rootdbs; 

----------------------------------------------------------------------
--DDL statements for primary key on table: "LREESCHEMA.POJOSTEP"
----------------------------------------------------------------------
ALTER TABLE LREESCHEMA.POJOSTEP 
     ADD CONSTRAINT PRIMARY KEY(JOBID,STEPID) CONSTRAINT PK_POJOSTEP;

  
-- COMMIT WORK;






